@@ -1,6 +1,6 @@
 pred.logit.env <- function(m, Xnew) {
   if (is.null(m$ratio)) 
-    stop("The asymptotic distribution part of env is missing. Rerun logit.env with asy = T")
+    stop("The asymptotic distribution part of logit.env is missing. Rerun logit.env with asy = T")
   n <- m$n
   r <- 1
   if (is.null(m$Gamma)) {
@@ -28,4 +28,4 @@ pred.logit.env <- function(m, Xnew) {
   SE.estm <- sqrt(diag(covMatrix.estm))
   return(list(value = value, covMatrix.estm = covMatrix.estm, 
               SE.estm = SE.estm))
-}
\ No newline at end of file
+}
