@@ -1,6 +1,6 @@
 pred.stenv <- function(m, Xnew){
   if (is.null(m$ratio)) 
-    stop("The asymptotic distribution part of env is missing. Rerun stenv with asy = T")
+    stop("The asymptotic distribution part of stenv is missing. Rerun stenv with asy = T")
   r <- ncol(m$SigmaYcX)
   n <- m$n
   if (is.null(m$Gamma)) {
@@ -32,4 +32,4 @@ pred.stenv <- function(m, Xnew){
   return(list(value = value, covMatrix.estm = covMatrix.estm, 
               SE.estm = SE.estm, covMatrix.pred = covMatrix.pred, SE.pred = SE.pred))
 
-}
\ No newline at end of file
+}
